Class: Google::Apis::MonitoringV3::BasicSli
- Inherits:
-
Object
- Object
- Google::Apis::MonitoringV3::BasicSli
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/monitoring_v3/classes.rb,
lib/google/apis/monitoring_v3/representations.rb,
lib/google/apis/monitoring_v3/representations.rb
Overview
An SLI measuring performance on a well-known service type. Performance will be computed on the basis of pre-defined metrics. The type of the service_resource determines the metrics to use and the service_resource.labels and metric_labels are used to construct a monitoring filter to filter that metric down to just the data relevant to this service.
Instance Attribute Summary collapse
-
#availability ⇒ Google::Apis::MonitoringV3::AvailabilityCriteria
Future parameters for the availability SLI.
-
#latency ⇒ Google::Apis::MonitoringV3::LatencyCriteria
Parameters for a latency threshold SLI.
-
#location ⇒ Array<String>
OPTIONAL: The set of locations to which this SLI is relevant.
-
#method_prop ⇒ Array<String>
OPTIONAL: The set of RPCs to which this SLI is relevant.
-
#version ⇒ Array<String>
OPTIONAL: The set of API versions to which this SLI is relevant.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BasicSli
constructor
A new instance of BasicSli.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BasicSli
Returns a new instance of BasicSli.
521 522 523 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 521 def initialize(**args) update!(**args) end |
Instance Attribute Details
#availability ⇒ Google::Apis::MonitoringV3::AvailabilityCriteria
Future parameters for the availability SLI.
Corresponds to the JSON property availability
489 490 491 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 489 def availability @availability end |
#latency ⇒ Google::Apis::MonitoringV3::LatencyCriteria
Parameters for a latency threshold SLI.
Corresponds to the JSON property latency
494 495 496 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 494 def latency @latency end |
#location ⇒ Array<String>
OPTIONAL: The set of locations to which this SLI is relevant. Telemetry from
other locations will not be used to calculate performance for this SLI. If
omitted, this SLI applies to all locations in which the Service has activity.
For service types that don't support breaking down by location, setting this
field will result in an error.
Corresponds to the JSON property location
503 504 505 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 503 def location @location end |
#method_prop ⇒ Array<String>
OPTIONAL: The set of RPCs to which this SLI is relevant. Telemetry from other
methods will not be used to calculate performance for this SLI. If omitted,
this SLI applies to all the Service's methods. For service types that don't
support breaking down by method, setting this field will result in an error.
Corresponds to the JSON property method
511 512 513 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 511 def method_prop @method_prop end |
#version ⇒ Array<String>
OPTIONAL: The set of API versions to which this SLI is relevant. Telemetry
from other API versions will not be used to calculate performance for this SLI.
If omitted, this SLI applies to all API versions. For service types that don'
t support breaking down by version, setting this field will result in an error.
Corresponds to the JSON property version
519 520 521 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 519 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
526 527 528 529 530 531 532 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 526 def update!(**args) @availability = args[:availability] if args.key?(:availability) @latency = args[:latency] if args.key?(:latency) @location = args[:location] if args.key?(:location) @method_prop = args[:method_prop] if args.key?(:method_prop) @version = args[:version] if args.key?(:version) end |