Class: Google::Apis::MonitoringV3::BooleanTest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/monitoring_v3/classes.rb,
lib/google/apis/monitoring_v3/representations.rb,
lib/google/apis/monitoring_v3/representations.rb

Overview

A test that uses an alerting result in a boolean column produced by the SQL query.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BooleanTest

Returns a new instance of BooleanTest.



546
547
548
# File 'lib/google/apis/monitoring_v3/classes.rb', line 546

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#columnString

Required. The name of the column containing the boolean value. If the value in a row is NULL, that row is ignored. Corresponds to the JSON property column

Returns:

  • (String)


544
545
546
# File 'lib/google/apis/monitoring_v3/classes.rb', line 544

def column
  @column
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



551
552
553
# File 'lib/google/apis/monitoring_v3/classes.rb', line 551

def update!(**args)
  @column = args[:column] if args.key?(:column)
end