Class: Google::Apis::MonitoringV3::CreateCollectdTimeSeriesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/monitoring_v3/classes.rb,
lib/google/apis/monitoring_v3/representations.rb,
lib/google/apis/monitoring_v3/representations.rb

Overview

The CreateCollectdTimeSeries response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CreateCollectdTimeSeriesResponse

Returns a new instance of CreateCollectdTimeSeriesResponse.



1110
1111
1112
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1110

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#payload_errorsArray<Google::Apis::MonitoringV3::CollectdPayloadError>

Records the error status for points that were not written due to an error in the request.Failed requests for which nothing is written will return an error response instead. Requests where data points were rejected by the backend will set summary instead. Corresponds to the JSON property payloadErrors



1103
1104
1105
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1103

def payload_errors
  @payload_errors
end

#summaryGoogle::Apis::MonitoringV3::CreateTimeSeriesSummary

Summary of the result of a failed request to write data to a time series. Corresponds to the JSON property summary



1108
1109
1110
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1108

def summary
  @summary
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1115
1116
1117
1118
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1115

def update!(**args)
  @payload_errors = args[:payload_errors] if args.key?(:payload_errors)
  @summary = args[:summary] if args.key?(:summary)
end