Class: Google::Apis::MonitoringV3::Distribution

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/monitoring_v3/classes.rb,
lib/google/apis/monitoring_v3/representations.rb,
lib/google/apis/monitoring_v3/representations.rb

Overview

Distribution contains summary statistics for a population of values. It optionally contains a histogram representing the distribution of those values across a set of buckets.The summary statistics are the count, mean, sum of the squared deviation from the mean, the minimum, and the maximum of the set of population of values. The histogram is based on a sequence of buckets and gives a count of values that fall into each bucket. The boundaries of the buckets are given either explicitly or by formulas for buckets of fixed or exponentially increasing widths.Although it is not forbidden, it is generally a bad idea to include non-finite values (infinities or NaNs) in the population of values, as this will render the mean and sum_of_squared_deviation fields meaningless.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Distribution

Returns a new instance of Distribution.



1095
1096
1097
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1095

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bucket_countsArray<Fixnum>

Required in the Cloud Monitoring API v3. The values for each bucket specified in bucket_options. The sum of the values in bucketCounts must equal the value in the count field of the Distribution object. The order of the bucket counts follows the numbering schemes described for the three bucket types. The underflow bucket has number 0; the finite buckets, if any, have numbers 1 through N-2; and the overflow bucket has number N-1. The size of bucket_counts must not be greater than N. If the size is less than N, then the remaining buckets are assigned values of zero. Corresponds to the JSON property bucketCounts

Returns:

  • (Array<Fixnum>)


1045
1046
1047
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1045

def bucket_counts
  @bucket_counts
end

#bucket_optionsGoogle::Apis::MonitoringV3::BucketOptions

BucketOptions describes the bucket boundaries used to create a histogram for the distribution. The buckets can be in a linear sequence, an exponential sequence, or each bucket can be specified explicitly. BucketOptions does not include the number of values in each bucket.A bucket has an inclusive lower bound and exclusive upper bound for the values that are counted for that bucket. The upper bound of a bucket must be strictly greater than the lower bound. The sequence of N buckets for a distribution consists of an underflow bucket (number 0), zero or more finite buckets (number 1 through N - 2) and an overflow bucket (number N - 1). The buckets are contiguous: the lower bound of bucket i (i > 0) is the same as the upper bound of bucket i - 1. The buckets span the whole range of finite values: lower bound of the underflow bucket is - infinity and the upper bound of the overflow bucket is +infinity. The finite buckets are so-called because both bounds are finite. Corresponds to the JSON property bucketOptions



1062
1063
1064
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1062

def bucket_options
  @bucket_options
end

#countFixnum

The number of values in the population. Must be non-negative. This value must equal the sum of the values in bucket_counts if a histogram is provided. Corresponds to the JSON property count

Returns:

  • (Fixnum)


1068
1069
1070
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1068

def count
  @count
end

#exemplarsArray<Google::Apis::MonitoringV3::Exemplar>

Must be in increasing order of value field. Corresponds to the JSON property exemplars



1073
1074
1075
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1073

def exemplars
  @exemplars
end

#meanFloat

The arithmetic mean of the values in the population. If count is zero then this field must be zero. Corresponds to the JSON property mean

Returns:

  • (Float)


1079
1080
1081
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1079

def mean
  @mean
end

#rangeGoogle::Apis::MonitoringV3::Range

The range of the population values. Corresponds to the JSON property range



1084
1085
1086
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1084

def range
  @range
end

#sum_of_squared_deviationFloat

The sum of squared deviations from the mean of the values in the population. For values x_i this is: Sumi=1..n Knuth, "The Art of Computer Programming", Vol. 2, page 232, 3rd edition describes Welford's method for accumulating this sum in one pass.If count is zero then this field must be zero. Corresponds to the JSON property sumOfSquaredDeviation

Returns:

  • (Float)


1093
1094
1095
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1093

def sum_of_squared_deviation
  @sum_of_squared_deviation
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1100
1101
1102
1103
1104
1105
1106
1107
1108
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1100

def update!(**args)
  @bucket_counts = args[:bucket_counts] if args.key?(:bucket_counts)
  @bucket_options = args[:bucket_options] if args.key?(:bucket_options)
  @count = args[:count] if args.key?(:count)
  @exemplars = args[:exemplars] if args.key?(:exemplars)
  @mean = args[:mean] if args.key?(:mean)
  @range = args[:range] if args.key?(:range)
  @sum_of_squared_deviation = args[:sum_of_squared_deviation] if args.key?(:sum_of_squared_deviation)
end