Class: Google::Apis::MonitoringV3::Documentation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/monitoring_v3/classes.rb,
lib/google/apis/monitoring_v3/representations.rb,
lib/google/apis/monitoring_v3/representations.rb

Overview

Documentation that is included in the notifications and incidents pertaining to this policy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Documentation

Returns a new instance of Documentation.



1427
1428
1429
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1427

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentString

The body of the documentation, interpreted according to mime_type. The content may not exceed 8,192 Unicode characters and may not exceed more than 10,240 bytes when encoded in UTF-8 format, whichever is smaller. This text can be templatized by using variables (https://cloud.google.com/monitoring/alerts/doc- variables#doc-vars). Corresponds to the JSON property content

Returns:

  • (String)


1397
1398
1399
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1397

def content
  @content
end

Optional. Links to content such as playbooks, repositories, and other resources. This field can contain up to 3 entries. Corresponds to the JSON property links



1403
1404
1405
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1403

def links
  @links
end

#mime_typeString

The format of the content field. Presently, only the value "text/markdown" is supported. See Markdown (https://en.wikipedia.org/wiki/Markdown) for more information. Corresponds to the JSON property mimeType

Returns:

  • (String)


1410
1411
1412
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1410

def mime_type
  @mime_type
end

#subjectString

Optional. The subject line of the notification. The subject line may not exceed 10,240 bytes. In notifications generated by this policy, the contents of the subject line after variable expansion will be truncated to 255 bytes or shorter at the latest UTF-8 character boundary. The 255-byte limit is recommended by this thread (https://stackoverflow.com/questions/1592291/what- is-the-email-subject-length-limit). It is both the limit imposed by some third- party ticketing products and it is common to define textual fields in databases as VARCHAR(255).The contents of the subject line can be templatized by using variables (https://cloud.google.com/monitoring/alerts/doc-variables# doc-vars). If this field is missing or empty, a default subject line will be generated. Corresponds to the JSON property subject

Returns:

  • (String)


1425
1426
1427
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1425

def subject
  @subject
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1432
1433
1434
1435
1436
1437
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1432

def update!(**args)
  @content = args[:content] if args.key?(:content)
  @links = args[:links] if args.key?(:links)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
  @subject = args[:subject] if args.key?(:subject)
end