Class: Google::Apis::MonitoringV3::Exponential
- Inherits:
-
Object
- Object
- Google::Apis::MonitoringV3::Exponential
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/monitoring_v3/classes.rb,
lib/google/apis/monitoring_v3/representations.rb,
lib/google/apis/monitoring_v3/representations.rb
Overview
Specifies an exponential sequence of buckets that have a width that is proportional to the value of the lower bound. Each bucket represents a constant relative uncertainty on a specific value in the bucket.There are num_finite_buckets + 2 (= N) buckets. Bucket i has the following boundaries: Upper bound (0 <= i < N-1): scale * (growth_factor ^ i).Lower bound (1 <= i < N): scale * (growth_factor ^ (i - 1)).
Instance Attribute Summary collapse
-
#growth_factor ⇒ Float
Must be greater than 1.
-
#num_finite_buckets ⇒ Fixnum
Must be greater than 0.
-
#scale ⇒ Float
Must be greater than 0.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Exponential
constructor
A new instance of Exponential.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Exponential
Returns a new instance of Exponential.
1605 1606 1607 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1605 def initialize(**args) update!(**args) end |
Instance Attribute Details
#growth_factor ⇒ Float
Must be greater than 1.
Corresponds to the JSON property growthFactor
1593 1594 1595 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1593 def growth_factor @growth_factor end |
#num_finite_buckets ⇒ Fixnum
Must be greater than 0.
Corresponds to the JSON property numFiniteBuckets
1598 1599 1600 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1598 def num_finite_buckets @num_finite_buckets end |
#scale ⇒ Float
Must be greater than 0.
Corresponds to the JSON property scale
1603 1604 1605 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1603 def scale @scale end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1610 1611 1612 1613 1614 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1610 def update!(**args) @growth_factor = args[:growth_factor] if args.key?(:growth_factor) @num_finite_buckets = args[:num_finite_buckets] if args.key?(:num_finite_buckets) @scale = args[:scale] if args.key?(:scale) end |