Class: Google::Apis::MonitoringV3::ForecastOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/monitoring_v3/classes.rb,
lib/google/apis/monitoring_v3/representations.rb,
lib/google/apis/monitoring_v3/representations.rb

Overview

Options used when forecasting the time series and testing the predicted value against the threshold.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ForecastOptions

Returns a new instance of ForecastOptions.



1439
1440
1441
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1439

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#forecast_horizonString

Required. The length of time into the future to forecast whether a time series will violate the threshold. If the predicted value is found to violate the threshold, and the violation is observed in all forecasts made for the configured duration, then the time series is considered to be failing. Corresponds to the JSON property forecastHorizon

Returns:

  • (String)


1437
1438
1439
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1437

def forecast_horizon
  @forecast_horizon
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1444
1445
1446
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1444

def update!(**args)
  @forecast_horizon = args[:forecast_horizon] if args.key?(:forecast_horizon)
end