Class: Google::Apis::MonitoringV3::GetNotificationChannelVerificationCodeRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/monitoring_v3/classes.rb,
lib/google/apis/monitoring_v3/representations.rb,
lib/google/apis/monitoring_v3/representations.rb

Overview

The GetNotificationChannelVerificationCode request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GetNotificationChannelVerificationCodeRequest

Returns a new instance of GetNotificationChannelVerificationCodeRequest.



1738
1739
1740
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1738

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#expire_timeString

The desired expiration time. If specified, the API will guarantee that the returned code will not be valid after the specified timestamp; however, the API cannot guarantee that the returned code will be valid for at least as long as the requested time (the API puts an upper bound on the amount of time for which a code may be valid). If omitted, a default expiration will be used, which may be less than the max permissible expiration (so specifying an expiration may extend the code's lifetime over omitting an expiration, even though the API does impose an upper limit on the maximum expiration that is permitted). Corresponds to the JSON property expireTime

Returns:

  • (String)


1736
1737
1738
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1736

def expire_time
  @expire_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1743
1744
1745
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1743

def update!(**args)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
end