Class: Google::Apis::MonitoringV3::Hourly

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/monitoring_v3/classes.rb,
lib/google/apis/monitoring_v3/representations.rb,
lib/google/apis/monitoring_v3/representations.rb

Overview

Used to schedule the query to run every so many hours.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Hourly

Returns a new instance of Hourly.



2031
2032
2033
# File 'lib/google/apis/monitoring_v3/classes.rb', line 2031

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#minute_offsetFixnum

Optional. The number of minutes after the hour (in UTC) to run the query. Must be greater than or equal to 0 minutes and less than or equal to 59 minutes. If left unspecified, then an arbitrary offset is used. Corresponds to the JSON property minuteOffset

Returns:

  • (Fixnum)


2023
2024
2025
# File 'lib/google/apis/monitoring_v3/classes.rb', line 2023

def minute_offset
  @minute_offset
end

#periodicityFixnum

Required. The number of hours between runs. Must be greater than or equal to 1 hour and less than or equal to 48 hours. Corresponds to the JSON property periodicity

Returns:

  • (Fixnum)


2029
2030
2031
# File 'lib/google/apis/monitoring_v3/classes.rb', line 2029

def periodicity
  @periodicity
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2036
2037
2038
2039
# File 'lib/google/apis/monitoring_v3/classes.rb', line 2036

def update!(**args)
  @minute_offset = args[:minute_offset] if args.key?(:minute_offset)
  @periodicity = args[:periodicity] if args.key?(:periodicity)
end