Class: Google::Apis::MonitoringV3::HttpCheck

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/monitoring_v3/classes.rb,
lib/google/apis/monitoring_v3/representations.rb,
lib/google/apis/monitoring_v3/representations.rb

Overview

Information involved in an HTTP/HTTPS Uptime check request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpCheck

Returns a new instance of HttpCheck.



1854
1855
1856
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1854

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accepted_response_status_codesArray<Google::Apis::MonitoringV3::ResponseStatusCode>

If present, the check will only pass if the HTTP response status code is in this set of status codes. If empty, the HTTP status code will only pass if the HTTP status code is 200-299. Corresponds to the JSON property acceptedResponseStatusCodes



1751
1752
1753
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1751

def accepted_response_status_codes
  @accepted_response_status_codes
end

#auth_infoGoogle::Apis::MonitoringV3::BasicAuthentication

The authentication parameters to provide to the specified resource or URL that requires a username and password. Currently, only Basic HTTP authentication ( https://tools.ietf.org/html/rfc7617) is supported in Uptime checks. Corresponds to the JSON property authInfo



1758
1759
1760
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1758

def auth_info
  @auth_info
end

#bodyString

The request body associated with the HTTP POST request. If content_type is URL_ENCODED, the body passed in must be URL-encoded. Users can provide a Content-Length header via the headers field or the API will do so. If the request_method is GET and body is not empty, the API will return an error. The maximum byte size is 1 megabyte.Note: If client libraries aren't used (which performs the conversion automatically) base64 encode your body data since the field is of bytes type. Corresponds to the JSON property body NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


1770
1771
1772
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1770

def body
  @body
end

#content_typeString

The content type header to use for the check. The following configurations result in errors: 1. Content type is specified in both the headers field and the content_type field. 2. Request method is GET and content_type is not TYPE_UNSPECIFIED 3. Request method is POST and content_type is TYPE_UNSPECIFIED. 4. Request method is POST and a "Content-Type" header is provided via headers field. The content_type field should be used instead. Corresponds to the JSON property contentType

Returns:

  • (String)


1780
1781
1782
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1780

def content_type
  @content_type
end

#custom_content_typeString

A user provided content type header to use for the check. The invalid configurations outlined in the content_type field apply to custom_content_type, as well as the following: 1. content_type is URL_ENCODED and custom_content_type is set. 2. content_type is USER_PROVIDED and custom_content_type is not set. Corresponds to the JSON property customContentType

Returns:

  • (String)


1789
1790
1791
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1789

def custom_content_type
  @custom_content_type
end

#headersHash<String,String>

The list of headers to send as part of the Uptime check request. If two headers have the same key and different values, they should be entered as a single header, with the value being a comma-separated list of all the desired values as described at https://www.w3.org/Protocols/rfc2616/rfc2616.txt (page 31). Entering two separate headers with the same key in a Create call will cause the first to be overwritten by the second. The maximum number of headers allowed is 100. Corresponds to the JSON property headers

Returns:

  • (Hash<String,String>)


1800
1801
1802
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1800

def headers
  @headers
end

#mask_headersBoolean Also known as: mask_headers?

Boolean specifying whether to encrypt the header information. Encryption should be specified for any headers related to authentication that you do not wish to be seen when retrieving the configuration. The server will be responsible for encrypting the headers. On Get/List calls, if mask_headers is set to true then the headers will be obscured with ******. Corresponds to the JSON property maskHeaders

Returns:

  • (Boolean)


1809
1810
1811
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1809

def mask_headers
  @mask_headers
end

#pathString

Optional (defaults to "/"). The path to the page against which to run the check. Will be combined with the host (specified within the monitored_resource) and port to construct the full URL. If the provided path does not begin with " /", a "/" will be prepended automatically. Corresponds to the JSON property path

Returns:

  • (String)


1818
1819
1820
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1818

def path
  @path
end

#ping_configGoogle::Apis::MonitoringV3::PingConfig

Information involved in sending ICMP pings alongside public HTTP/TCP checks. For HTTP, the pings are performed for each part of the redirect chain. Corresponds to the JSON property pingConfig



1824
1825
1826
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1824

def ping_config
  @ping_config
end

#portFixnum

Optional (defaults to 80 when use_ssl is false, and 443 when use_ssl is true). The TCP port on the HTTP server against which to run the check. Will be combined with host (specified within the monitored_resource) and path to construct the full URL. Corresponds to the JSON property port

Returns:

  • (Fixnum)


1832
1833
1834
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1832

def port
  @port
end

#request_methodString

The HTTP request method to use for the check. If set to METHOD_UNSPECIFIED then request_method defaults to GET. Corresponds to the JSON property requestMethod

Returns:

  • (String)


1838
1839
1840
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1838

def request_method
  @request_method
end

#use_sslBoolean Also known as: use_ssl?

If true, use HTTPS instead of HTTP to run the check. Corresponds to the JSON property useSsl

Returns:

  • (Boolean)


1843
1844
1845
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1843

def use_ssl
  @use_ssl
end

#validate_sslBoolean Also known as: validate_ssl?

Boolean specifying whether to include SSL certificate validation as a part of the Uptime check. Only applies to checks where monitored_resource is set to uptime_url. If use_ssl is false, setting validate_ssl to true has no effect. Corresponds to the JSON property validateSsl

Returns:

  • (Boolean)


1851
1852
1853
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1851

def validate_ssl
  @validate_ssl
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1859

def update!(**args)
  @accepted_response_status_codes = args[:accepted_response_status_codes] if args.key?(:accepted_response_status_codes)
  @auth_info = args[:auth_info] if args.key?(:auth_info)
  @body = args[:body] if args.key?(:body)
  @content_type = args[:content_type] if args.key?(:content_type)
  @custom_content_type = args[:custom_content_type] if args.key?(:custom_content_type)
  @headers = args[:headers] if args.key?(:headers)
  @mask_headers = args[:mask_headers] if args.key?(:mask_headers)
  @path = args[:path] if args.key?(:path)
  @ping_config = args[:ping_config] if args.key?(:ping_config)
  @port = args[:port] if args.key?(:port)
  @request_method = args[:request_method] if args.key?(:request_method)
  @use_ssl = args[:use_ssl] if args.key?(:use_ssl)
  @validate_ssl = args[:validate_ssl] if args.key?(:validate_ssl)
end