Class: Google::Apis::MonitoringV3::LatencyCriteria
- Inherits:
-
Object
- Object
- Google::Apis::MonitoringV3::LatencyCriteria
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/monitoring_v3/classes.rb,
lib/google/apis/monitoring_v3/representations.rb,
lib/google/apis/monitoring_v3/representations.rb
Overview
Parameters for a latency threshold SLI.
Instance Attribute Summary collapse
-
#threshold ⇒ String
Good service is defined to be the count of requests made to this service that return in no more than threshold.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LatencyCriteria
constructor
A new instance of LatencyCriteria.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LatencyCriteria
Returns a new instance of LatencyCriteria.
2077 2078 2079 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 2077 def initialize(**args) update!(**args) end |
Instance Attribute Details
#threshold ⇒ String
Good service is defined to be the count of requests made to this service that
return in no more than threshold.
Corresponds to the JSON property threshold
2075 2076 2077 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 2075 def threshold @threshold end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2082 2083 2084 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 2082 def update!(**args) @threshold = args[:threshold] if args.key?(:threshold) end |