Class: Google::Apis::MonitoringV3::ListUptimeCheckConfigsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/monitoring_v3/classes.rb,
lib/google/apis/monitoring_v3/representations.rb,
lib/google/apis/monitoring_v3/representations.rb

Overview

The protocol for the ListUptimeCheckConfigs response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListUptimeCheckConfigsResponse

Returns a new instance of ListUptimeCheckConfigsResponse.



2862
2863
2864
# File 'lib/google/apis/monitoring_v3/classes.rb', line 2862

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

This field represents the pagination token to retrieve the next page of results. If the value is empty, it means no further results for the request. To retrieve the next page of results, the value of the next_page_token is passed to the subsequent List method call (in the request message's page_token field). Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2849
2850
2851
# File 'lib/google/apis/monitoring_v3/classes.rb', line 2849

def next_page_token
  @next_page_token
end

#total_sizeFixnum

The total number of Uptime check configurations for the project, irrespective of any pagination. Corresponds to the JSON property totalSize

Returns:

  • (Fixnum)


2855
2856
2857
# File 'lib/google/apis/monitoring_v3/classes.rb', line 2855

def total_size
  @total_size
end

#uptime_check_configsArray<Google::Apis::MonitoringV3::UptimeCheckConfig>

The returned Uptime check configurations. Corresponds to the JSON property uptimeCheckConfigs



2860
2861
2862
# File 'lib/google/apis/monitoring_v3/classes.rb', line 2860

def uptime_check_configs
  @uptime_check_configs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2867
2868
2869
2870
2871
# File 'lib/google/apis/monitoring_v3/classes.rb', line 2867

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @total_size = args[:total_size] if args.key?(:total_size)
  @uptime_check_configs = args[:uptime_check_configs] if args.key?(:uptime_check_configs)
end