Class: Google::Apis::MonitoringV3::MetricAbsence

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/monitoring_v3/classes.rb,
lib/google/apis/monitoring_v3/representations.rb,
lib/google/apis/monitoring_v3/representations.rb

Overview

A condition type that checks that monitored resources are reporting data. The configuration defines a metric and a set of monitored resources. The predicate is considered in violation when a time series for the specified metric of a monitored resource does not include any data in the specified duration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MetricAbsence

Returns a new instance of MetricAbsence.



3068
3069
3070
# File 'lib/google/apis/monitoring_v3/classes.rb', line 3068

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aggregationsArray<Google::Apis::MonitoringV3::Aggregation>

Specifies the alignment of data points in individual time series as well as how to combine the retrieved time series together (such as when aggregating multiple streams on each resource to a single stream for each resource or when aggregating streams across all members of a group of resources). Multiple aggregations are applied in the order specified.This field is similar to the one in the ListTimeSeries request (https://cloud.google.com/monitoring/api/ ref_v3/rest/v3/projects.timeSeries/list). It is advisable to use the ListTimeSeries method when debugging this field. Corresponds to the JSON property aggregations



3040
3041
3042
# File 'lib/google/apis/monitoring_v3/classes.rb', line 3040

def aggregations
  @aggregations
end

#durationString

Required. The amount of time that a time series must fail to report new data to be considered failing. The minimum value of this field is 120 seconds. Larger values that are a multiple of a minute--for example, 240 or 300 seconds- -are supported. If an invalid value is given, an error will be returned. Corresponds to the JSON property duration

Returns:

  • (String)


3048
3049
3050
# File 'lib/google/apis/monitoring_v3/classes.rb', line 3048

def duration
  @duration
end

#filterString

Required. A filter (https://cloud.google.com/monitoring/api/v3/filters) that identifies which time series should be compared with the threshold.The filter is similar to the one that is specified in the ListTimeSeries request (https:// cloud.google.com/monitoring/api/ref_v3/rest/v3/projects.timeSeries/list) (that call is useful to verify the time series that will be retrieved / processed). The filter must specify the metric type and the resource type. Optionally, it can specify resource labels and metric labels. This field must not exceed 2048 Unicode characters in length. Corresponds to the JSON property filter

Returns:

  • (String)


3060
3061
3062
# File 'lib/google/apis/monitoring_v3/classes.rb', line 3060

def filter
  @filter
end

#triggerGoogle::Apis::MonitoringV3::Trigger

Specifies how many time series must fail a predicate to trigger a condition. If not specified, then a count: 1 trigger is used. Corresponds to the JSON property trigger



3066
3067
3068
# File 'lib/google/apis/monitoring_v3/classes.rb', line 3066

def trigger
  @trigger
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3073
3074
3075
3076
3077
3078
# File 'lib/google/apis/monitoring_v3/classes.rb', line 3073

def update!(**args)
  @aggregations = args[:aggregations] if args.key?(:aggregations)
  @duration = args[:duration] if args.key?(:duration)
  @filter = args[:filter] if args.key?(:filter)
  @trigger = args[:trigger] if args.key?(:trigger)
end