Class: Google::Apis::MonitoringV3::Minutes

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/monitoring_v3/classes.rb,
lib/google/apis/monitoring_v3/representations.rb,
lib/google/apis/monitoring_v3/representations.rb

Overview

Used to schedule the query to run every so many minutes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Minutes

Returns a new instance of Minutes.



3416
3417
3418
# File 'lib/google/apis/monitoring_v3/classes.rb', line 3416

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#periodicityFixnum

Required. Number of minutes between runs. The interval must be greater than or equal to 5 minutes and less than or equal to 1440 minutes. Corresponds to the JSON property periodicity

Returns:

  • (Fixnum)


3414
3415
3416
# File 'lib/google/apis/monitoring_v3/classes.rb', line 3414

def periodicity
  @periodicity
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3421
3422
3423
# File 'lib/google/apis/monitoring_v3/classes.rb', line 3421

def update!(**args)
  @periodicity = args[:periodicity] if args.key?(:periodicity)
end