Class: Google::Apis::MonitoringV3::MonitoringQueryLanguageCondition

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/monitoring_v3/classes.rb,
lib/google/apis/monitoring_v3/representations.rb,
lib/google/apis/monitoring_v3/representations.rb

Overview

A condition type that allows alerting policies to be defined using Monitoring Query Language (https://cloud.google.com/monitoring/mql).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MonitoringQueryLanguageCondition

Returns a new instance of MonitoringQueryLanguageCondition.



3604
3605
3606
# File 'lib/google/apis/monitoring_v3/classes.rb', line 3604

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#durationString

Optional. The amount of time that a time series must violate the threshold to be considered failing. Currently, only values that are a multiple of a minute-- e.g., 0, 60, 120, or 300 seconds--are supported. If an invalid value is given, an error will be returned. When choosing a duration, it is useful to keep in mind the frequency of the underlying time series data (which may also be affected by any alignments specified in the aggregations field); a good duration is long enough so that a single outlier does not generate spurious alerts, but short enough that unhealthy states are detected and alerted on quickly. The default value is zero. Corresponds to the JSON property duration

Returns:

  • (String)


3584
3585
3586
# File 'lib/google/apis/monitoring_v3/classes.rb', line 3584

def duration
  @duration
end

#evaluation_missing_dataString

A condition control that determines how metric-threshold conditions are evaluated when data stops arriving. Corresponds to the JSON property evaluationMissingData

Returns:

  • (String)


3590
3591
3592
# File 'lib/google/apis/monitoring_v3/classes.rb', line 3590

def evaluation_missing_data
  @evaluation_missing_data
end

#queryString

Monitoring Query Language (https://cloud.google.com/monitoring/mql) query that outputs a boolean stream. Corresponds to the JSON property query

Returns:

  • (String)


3596
3597
3598
# File 'lib/google/apis/monitoring_v3/classes.rb', line 3596

def query
  @query
end

#triggerGoogle::Apis::MonitoringV3::Trigger

Specifies how many time series must fail a predicate to trigger a condition. If not specified, then a count: 1 trigger is used. Corresponds to the JSON property trigger



3602
3603
3604
# File 'lib/google/apis/monitoring_v3/classes.rb', line 3602

def trigger
  @trigger
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3609
3610
3611
3612
3613
3614
# File 'lib/google/apis/monitoring_v3/classes.rb', line 3609

def update!(**args)
  @duration = args[:duration] if args.key?(:duration)
  @evaluation_missing_data = args[:evaluation_missing_data] if args.key?(:evaluation_missing_data)
  @query = args[:query] if args.key?(:query)
  @trigger = args[:trigger] if args.key?(:trigger)
end