Class: Google::Apis::MonitoringV3::NotificationChannelDescriptor

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/monitoring_v3/classes.rb,
lib/google/apis/monitoring_v3/representations.rb,
lib/google/apis/monitoring_v3/representations.rb

Overview

A description of a notification channel. The descriptor includes the properties of the channel and the set of labels or fields that must be specified to configure channels of a given type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NotificationChannelDescriptor

Returns a new instance of NotificationChannelDescriptor.



3802
3803
3804
# File 'lib/google/apis/monitoring_v3/classes.rb', line 3802

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

A human-readable description of the notification channel type. The description may include a description of the properties of the channel and pointers to external documentation. Corresponds to the JSON property description

Returns:

  • (String)


3762
3763
3764
# File 'lib/google/apis/monitoring_v3/classes.rb', line 3762

def description
  @description
end

#display_nameString

A human-readable name for the notification channel type. This form of the name is suitable for a user interface. Corresponds to the JSON property displayName

Returns:

  • (String)


3768
3769
3770
# File 'lib/google/apis/monitoring_v3/classes.rb', line 3768

def display_name
  @display_name
end

#labelsArray<Google::Apis::MonitoringV3::LabelDescriptor>

The set of labels that must be defined to identify a particular channel of the corresponding type. Each label includes a description for how that field should be populated. Corresponds to the JSON property labels



3775
3776
3777
# File 'lib/google/apis/monitoring_v3/classes.rb', line 3775

def labels
  @labels
end

#launch_stageString

The product launch stage for channels of this type. Corresponds to the JSON property launchStage

Returns:

  • (String)


3780
3781
3782
# File 'lib/google/apis/monitoring_v3/classes.rb', line 3780

def launch_stage
  @launch_stage
end

#nameString

The full REST resource name for this descriptor. The format is: projects/[ PROJECT_ID_OR_NUMBER]/notificationChannelDescriptors/[TYPE] In the above, [ TYPE] is the value of the type field. Corresponds to the JSON property name

Returns:

  • (String)


3787
3788
3789
# File 'lib/google/apis/monitoring_v3/classes.rb', line 3787

def name
  @name
end

#supported_tiersArray<String>

The tiers that support this notification channel; the project service tier must be one of the supported_tiers. Corresponds to the JSON property supportedTiers

Returns:

  • (Array<String>)


3793
3794
3795
# File 'lib/google/apis/monitoring_v3/classes.rb', line 3793

def supported_tiers
  @supported_tiers
end

#typeString

The type of notification channel, such as "email" and "sms". To view the full list of channels, see Channel descriptors (https://cloud.google.com/monitoring/ alerts/using-channels-api#ncd). Notification channel types are globally unique. Corresponds to the JSON property type

Returns:

  • (String)


3800
3801
3802
# File 'lib/google/apis/monitoring_v3/classes.rb', line 3800

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3807
3808
3809
3810
3811
3812
3813
3814
3815
# File 'lib/google/apis/monitoring_v3/classes.rb', line 3807

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @labels = args[:labels] if args.key?(:labels)
  @launch_stage = args[:launch_stage] if args.key?(:launch_stage)
  @name = args[:name] if args.key?(:name)
  @supported_tiers = args[:supported_tiers] if args.key?(:supported_tiers)
  @type = args[:type] if args.key?(:type)
end