Class: Google::Apis::MonitoringV3::NotificationChannelStrategy
- Inherits:
-
Object
- Object
- Google::Apis::MonitoringV3::NotificationChannelStrategy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/monitoring_v3/classes.rb,
lib/google/apis/monitoring_v3/representations.rb,
lib/google/apis/monitoring_v3/representations.rb
Overview
Control over how the notification channels in notification_channels are notified when this alert fires, on a per-channel basis.
Instance Attribute Summary collapse
-
#notification_channel_names ⇒ Array<String>
The full REST resource name for the notification channels that these settings apply to.
-
#renotify_interval ⇒ String
The frequency at which to send reminder notifications for open incidents.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NotificationChannelStrategy
constructor
A new instance of NotificationChannelStrategy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NotificationChannelStrategy
Returns a new instance of NotificationChannelStrategy.
3838 3839 3840 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 3838 def initialize(**args) update!(**args) end |
Instance Attribute Details
#notification_channel_names ⇒ Array<String>
The full REST resource name for the notification channels that these settings
apply to. Each of these correspond to the name field in one of the
NotificationChannel objects referenced in the notification_channels field of
this AlertPolicy. The format is: projects/[PROJECT_ID_OR_NUMBER]/
notificationChannels/[CHANNEL_ID]
Corresponds to the JSON property notificationChannelNames
3830 3831 3832 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 3830 def notification_channel_names @notification_channel_names end |
#renotify_interval ⇒ String
The frequency at which to send reminder notifications for open incidents. The
value must be between 30 minutes and 24 hours.
Corresponds to the JSON property renotifyInterval
3836 3837 3838 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 3836 def renotify_interval @renotify_interval end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3843 3844 3845 3846 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 3843 def update!(**args) @notification_channel_names = args[:notification_channel_names] if args.key?(:notification_channel_names) @renotify_interval = args[:renotify_interval] if args.key?(:renotify_interval) end |