Class: Google::Apis::MonitoringV3::RowCountTest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/monitoring_v3/classes.rb,
lib/google/apis/monitoring_v3/representations.rb,
lib/google/apis/monitoring_v3/representations.rb

Overview

A test that checks if the number of rows in the result set violates some threshold.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RowCountTest

Returns a new instance of RowCountTest.



4455
4456
4457
# File 'lib/google/apis/monitoring_v3/classes.rb', line 4455

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#comparisonString

Required. The comparison to apply between the number of rows returned by the query and the threshold. Corresponds to the JSON property comparison

Returns:

  • (String)


4448
4449
4450
# File 'lib/google/apis/monitoring_v3/classes.rb', line 4448

def comparison
  @comparison
end

#thresholdFixnum

Required. The value against which to compare the row count. Corresponds to the JSON property threshold

Returns:

  • (Fixnum)


4453
4454
4455
# File 'lib/google/apis/monitoring_v3/classes.rb', line 4453

def threshold
  @threshold
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4460
4461
4462
4463
# File 'lib/google/apis/monitoring_v3/classes.rb', line 4460

def update!(**args)
  @comparison = args[:comparison] if args.key?(:comparison)
  @threshold = args[:threshold] if args.key?(:threshold)
end