Class: Google::Apis::MonitoringV3::SyntheticMonitorTarget

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/monitoring_v3/classes.rb,
lib/google/apis/monitoring_v3/representations.rb,
lib/google/apis/monitoring_v3/representations.rb

Overview

Describes a Synthetic Monitor to be invoked by Uptime.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SyntheticMonitorTarget

Returns a new instance of SyntheticMonitorTarget.



4984
4985
4986
# File 'lib/google/apis/monitoring_v3/classes.rb', line 4984

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cloud_function_v2Google::Apis::MonitoringV3::CloudFunctionV2Target

A Synthetic Monitor deployed to a Cloud Functions V2 instance. Corresponds to the JSON property cloudFunctionV2



4982
4983
4984
# File 'lib/google/apis/monitoring_v3/classes.rb', line 4982

def cloud_function_v2
  @cloud_function_v2
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4989
4990
4991
# File 'lib/google/apis/monitoring_v3/classes.rb', line 4989

def update!(**args)
  @cloud_function_v2 = args[:cloud_function_v2] if args.key?(:cloud_function_v2)
end