Class: Google::Apis::MonitoringV3::UptimeCheckConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/monitoring_v3/classes.rb,
lib/google/apis/monitoring_v3/representations.rb,
lib/google/apis/monitoring_v3/representations.rb

Overview

This message configures which resources and services to monitor for availability.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UptimeCheckConfig

Returns a new instance of UptimeCheckConfig.



5610
5611
5612
# File 'lib/google/apis/monitoring_v3/classes.rb', line 5610

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#checker_typeString

The type of checkers to use to execute the Uptime check. Corresponds to the JSON property checkerType

Returns:

  • (String)


5489
5490
5491
# File 'lib/google/apis/monitoring_v3/classes.rb', line 5489

def checker_type
  @checker_type
end

#content_matchersArray<Google::Apis::MonitoringV3::ContentMatcher>

The content that is expected to appear in the data returned by the target server against which the check is run. Currently, only the first entry in the content_matchers list is supported, and additional entries will be ignored. This field is optional and should only be specified if a content match is required as part of the/ Uptime check. Corresponds to the JSON property contentMatchers



5498
5499
5500
# File 'lib/google/apis/monitoring_v3/classes.rb', line 5498

def content_matchers
  @content_matchers
end

#disabledBoolean Also known as: disabled?

Whether the check is disabled or not. Corresponds to the JSON property disabled

Returns:

  • (Boolean)


5503
5504
5505
# File 'lib/google/apis/monitoring_v3/classes.rb', line 5503

def disabled
  @disabled
end

#display_nameString

A human-friendly name for the Uptime check configuration. The display name should be unique within a Cloud Monitoring Workspace in order to make it easier to identify; however, uniqueness is not enforced. Required. Corresponds to the JSON property displayName

Returns:

  • (String)


5511
5512
5513
# File 'lib/google/apis/monitoring_v3/classes.rb', line 5511

def display_name
  @display_name
end

#http_checkGoogle::Apis::MonitoringV3::HttpCheck

Information involved in an HTTP/HTTPS Uptime check request. Corresponds to the JSON property httpCheck



5516
5517
5518
# File 'lib/google/apis/monitoring_v3/classes.rb', line 5516

def http_check
  @http_check
end

#internal_checkersArray<Google::Apis::MonitoringV3::InternalChecker>

The internal checkers that this check will egress from. If is_internal is true and this list is empty, the check will egress from all the InternalCheckers configured for the project that owns this UptimeCheckConfig. Corresponds to the JSON property internalCheckers



5523
5524
5525
# File 'lib/google/apis/monitoring_v3/classes.rb', line 5523

def internal_checkers
  @internal_checkers
end

#is_internalBoolean Also known as: is_internal?

If this is true, then checks are made only from the 'internal_checkers'. If it is false, then checks are made only from the 'selected_regions'. It is an error to provide 'selected_regions' when is_internal is true, or to provide ' internal_checkers' when is_internal is false. Corresponds to the JSON property isInternal

Returns:

  • (Boolean)


5531
5532
5533
# File 'lib/google/apis/monitoring_v3/classes.rb', line 5531

def is_internal
  @is_internal
end

#log_check_failuresBoolean Also known as: log_check_failures?

To specify whether to log the results of failed probes to Cloud Logging. Corresponds to the JSON property logCheckFailures

Returns:

  • (Boolean)


5537
5538
5539
# File 'lib/google/apis/monitoring_v3/classes.rb', line 5537

def log_check_failures
  @log_check_failures
end

#monitored_resourceGoogle::Apis::MonitoringV3::MonitoredResource

An object representing a resource that can be used for monitoring, logging, billing, or other purposes. Examples include virtual machine instances, databases, and storage devices such as disks. The type field identifies a MonitoredResourceDescriptor object that describes the resource's schema. Information in the labels field identifies the actual resource and its attributes according to the schema. For example, a particular Compute Engine VM instance could be represented by the following object, because the MonitoredResourceDescriptor for "gce_instance" has labels "project_id", " instance_id" and "zone": "type": "gce_instance", "labels": "project_id": " my-project", "instance_id": "12345678901234", "zone": "us-central1-a" ` Corresponds to the JSON propertymonitoredResource`



5552
5553
5554
# File 'lib/google/apis/monitoring_v3/classes.rb', line 5552

def monitored_resource
  @monitored_resource
end

#nameString

Identifier. A unique resource name for this Uptime check configuration. The format is: projects/[PROJECT_ID_OR_NUMBER]/uptimeCheckConfigs/[UPTIME_CHECK_ID] [PROJECT_ID_OR_NUMBER] is the Workspace host project associated with the Uptime check.This field should be omitted when creating the Uptime check configuration; on create, the resource name is assigned by the server and included in the response. Corresponds to the JSON property name

Returns:

  • (String)


5562
5563
5564
# File 'lib/google/apis/monitoring_v3/classes.rb', line 5562

def name
  @name
end

#periodString

How often, in seconds, the Uptime check is performed. Currently, the only supported values are 60s (1 minute), 300s (5 minutes), 600s (10 minutes), and 900s (15 minutes). Optional, defaults to 60s. Corresponds to the JSON property period

Returns:

  • (String)


5569
5570
5571
# File 'lib/google/apis/monitoring_v3/classes.rb', line 5569

def period
  @period
end

#resource_groupGoogle::Apis::MonitoringV3::ResourceGroup

The resource submessage for group checks. It can be used instead of a monitored resource, when multiple resources are being monitored. Corresponds to the JSON property resourceGroup



5575
5576
5577
# File 'lib/google/apis/monitoring_v3/classes.rb', line 5575

def resource_group
  @resource_group
end

#selected_regionsArray<String>

The list of regions from which the check will be run. Some regions contain one location, and others contain more than one. If this field is specified, enough regions must be provided to include a minimum of 3 locations. Not specifying this field will result in Uptime checks running from all available regions. Corresponds to the JSON property selectedRegions

Returns:

  • (Array<String>)


5583
5584
5585
# File 'lib/google/apis/monitoring_v3/classes.rb', line 5583

def selected_regions
  @selected_regions
end

#synthetic_monitorGoogle::Apis::MonitoringV3::SyntheticMonitorTarget

Describes a Synthetic Monitor to be invoked by Uptime. Corresponds to the JSON property syntheticMonitor



5588
5589
5590
# File 'lib/google/apis/monitoring_v3/classes.rb', line 5588

def synthetic_monitor
  @synthetic_monitor
end

#tcp_checkGoogle::Apis::MonitoringV3::TcpCheck

Information required for a TCP Uptime check request. Corresponds to the JSON property tcpCheck



5593
5594
5595
# File 'lib/google/apis/monitoring_v3/classes.rb', line 5593

def tcp_check
  @tcp_check
end

#timeoutString

The maximum amount of time to wait for the request to complete (must be between 1 and 60 seconds). Required. Corresponds to the JSON property timeout

Returns:

  • (String)


5599
5600
5601
# File 'lib/google/apis/monitoring_v3/classes.rb', line 5599

def timeout
  @timeout
end

#user_labelsHash<String,String>

User-supplied key/value data to be used for organizing and identifying the UptimeCheckConfig objects.The field can contain up to 64 entries. Each key and value is limited to 63 Unicode characters or 128 bytes, whichever is smaller. Labels and values can contain only lowercase letters, numerals, underscores, and dashes. Keys must begin with a letter. Corresponds to the JSON property userLabels

Returns:

  • (Hash<String,String>)


5608
5609
5610
# File 'lib/google/apis/monitoring_v3/classes.rb', line 5608

def user_labels
  @user_labels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5615
5616
5617
5618
5619
5620
5621
5622
5623
5624
5625
5626
5627
5628
5629
5630
5631
5632
5633
# File 'lib/google/apis/monitoring_v3/classes.rb', line 5615

def update!(**args)
  @checker_type = args[:checker_type] if args.key?(:checker_type)
  @content_matchers = args[:content_matchers] if args.key?(:content_matchers)
  @disabled = args[:disabled] if args.key?(:disabled)
  @display_name = args[:display_name] if args.key?(:display_name)
  @http_check = args[:http_check] if args.key?(:http_check)
  @internal_checkers = args[:internal_checkers] if args.key?(:internal_checkers)
  @is_internal = args[:is_internal] if args.key?(:is_internal)
  @log_check_failures = args[:log_check_failures] if args.key?(:log_check_failures)
  @monitored_resource = args[:monitored_resource] if args.key?(:monitored_resource)
  @name = args[:name] if args.key?(:name)
  @period = args[:period] if args.key?(:period)
  @resource_group = args[:resource_group] if args.key?(:resource_group)
  @selected_regions = args[:selected_regions] if args.key?(:selected_regions)
  @synthetic_monitor = args[:synthetic_monitor] if args.key?(:synthetic_monitor)
  @tcp_check = args[:tcp_check] if args.key?(:tcp_check)
  @timeout = args[:timeout] if args.key?(:timeout)
  @user_labels = args[:user_labels] if args.key?(:user_labels)
end