Class: Google::Apis::MonitoringV3::UptimeCheckIp

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/monitoring_v3/classes.rb,
lib/google/apis/monitoring_v3/representations.rb,
lib/google/apis/monitoring_v3/representations.rb

Overview

Contains the region, location, and list of IP addresses where checkers in the location run from.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UptimeCheckIp

Returns a new instance of UptimeCheckIp.



5662
5663
5664
# File 'lib/google/apis/monitoring_v3/classes.rb', line 5662

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ip_addressString

The IP address from which the Uptime check originates. This is a fully specified IP address (not an IP address range). Most IP addresses, as of this publication, are in IPv4 format; however, one should not rely on the IP addresses being in IPv4 format indefinitely, and should support interpreting this field in either IPv4 or IPv6 format. Corresponds to the JSON property ipAddress

Returns:

  • (String)


5648
5649
5650
# File 'lib/google/apis/monitoring_v3/classes.rb', line 5648

def ip_address
  @ip_address
end

#locationString

A more specific location within the region that typically encodes a particular city/town/metro (and its containing state/province or country) within the broader umbrella region category. Corresponds to the JSON property location

Returns:

  • (String)


5655
5656
5657
# File 'lib/google/apis/monitoring_v3/classes.rb', line 5655

def location
  @location
end

#regionString

A broad region category in which the IP address is located. Corresponds to the JSON property region

Returns:

  • (String)


5660
5661
5662
# File 'lib/google/apis/monitoring_v3/classes.rb', line 5660

def region
  @region
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5667
5668
5669
5670
5671
# File 'lib/google/apis/monitoring_v3/classes.rb', line 5667

def update!(**args)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @location = args[:location] if args.key?(:location)
  @region = args[:region] if args.key?(:region)
end