Class: Google::Apis::MonitoringV3::CollectdPayloadError
- Inherits:
-
Object
- Object
- Google::Apis::MonitoringV3::CollectdPayloadError
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/monitoring_v3/classes.rb,
lib/google/apis/monitoring_v3/representations.rb,
lib/google/apis/monitoring_v3/representations.rb
Overview
Describes the error status for payloads that were not written.
Instance Attribute Summary collapse
-
#error ⇒ Google::Apis::MonitoringV3::Status
The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs.
-
#index ⇒ Fixnum
The zero-based index in CreateCollectdTimeSeriesRequest.collectd_payloads.
-
#value_errors ⇒ Array<Google::Apis::MonitoringV3::CollectdValueError>
Records the error status for values that were not written due to an error.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CollectdPayloadError
constructor
A new instance of CollectdPayloadError.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CollectdPayloadError
Returns a new instance of CollectdPayloadError.
830 831 832 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 830 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error ⇒ Google::Apis::MonitoringV3::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by gRPC
(https://github.com/grpc). Each Status message contains three pieces of data:
error code, error message, and error details.You can find out more about this
error model and how to work with it in the API Design Guide (https://cloud.
google.com/apis/design/errors).
Corresponds to the JSON property error
816 817 818 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 816 def error @error end |
#index ⇒ Fixnum
The zero-based index in CreateCollectdTimeSeriesRequest.collectd_payloads.
Corresponds to the JSON property index
821 822 823 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 821 def index @index end |
#value_errors ⇒ Array<Google::Apis::MonitoringV3::CollectdValueError>
Records the error status for values that were not written due to an error.
Failed payloads for which nothing is written will not include partial value
errors.
Corresponds to the JSON property valueErrors
828 829 830 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 828 def value_errors @value_errors end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
835 836 837 838 839 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 835 def update!(**args) @error = args[:error] if args.key?(:error) @index = args[:index] if args.key?(:index) @value_errors = args[:value_errors] if args.key?(:value_errors) end |