Class: Google::Apis::MonitoringV3::CreateCollectdTimeSeriesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/monitoring_v3/classes.rb,
lib/google/apis/monitoring_v3/representations.rb,
lib/google/apis/monitoring_v3/representations.rb

Overview

The CreateCollectdTimeSeries response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CreateCollectdTimeSeriesResponse

Returns a new instance of CreateCollectdTimeSeriesResponse.



916
917
918
# File 'lib/google/apis/monitoring_v3/classes.rb', line 916

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#payload_errorsArray<Google::Apis::MonitoringV3::CollectdPayloadError>

Records the error status for points that were not written due to an error in the request.Failed requests for which nothing is written will return an error response instead. Requests where data points were rejected by the backend will set summary instead. Corresponds to the JSON property payloadErrors



909
910
911
# File 'lib/google/apis/monitoring_v3/classes.rb', line 909

def payload_errors
  @payload_errors
end

#summaryGoogle::Apis::MonitoringV3::CreateTimeSeriesSummary

Summary of the result of a failed request to write data to a time series. Corresponds to the JSON property summary



914
915
916
# File 'lib/google/apis/monitoring_v3/classes.rb', line 914

def summary
  @summary
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



921
922
923
924
# File 'lib/google/apis/monitoring_v3/classes.rb', line 921

def update!(**args)
  @payload_errors = args[:payload_errors] if args.key?(:payload_errors)
  @summary = args[:summary] if args.key?(:summary)
end