Class: Google::Apis::MonitoringV3::Criteria
- Inherits:
-
Object
- Object
- Google::Apis::MonitoringV3::Criteria
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/monitoring_v3/classes.rb,
lib/google/apis/monitoring_v3/representations.rb,
lib/google/apis/monitoring_v3/representations.rb
Overview
Criteria specific to the AlertPolicys that this Snooze applies to. The Snooze will suppress alerts that come from one of the AlertPolicys whose names are supplied.
Instance Attribute Summary collapse
-
#policies ⇒ Array<String>
The specific AlertPolicy names for the alert that should be snoozed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Criteria
constructor
A new instance of Criteria.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Criteria
Returns a new instance of Criteria.
996 997 998 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 996 def initialize(**args) update!(**args) end |
Instance Attribute Details
#policies ⇒ Array<String>
The specific AlertPolicy names for the alert that should be snoozed. The
format is: projects/[PROJECT_ID_OR_NUMBER]/alertPolicies/[POLICY_ID] There is
a limit of 16 policies per snooze. This limit is checked during snooze
creation.
Corresponds to the JSON property policies
994 995 996 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 994 def policies @policies end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1001 1002 1003 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1001 def update!(**args) @policies = args[:policies] if args.key?(:policies) end |