Class: Google::Apis::MonitoringV3::Daily
- Inherits:
-
Object
- Object
- Google::Apis::MonitoringV3::Daily
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/monitoring_v3/classes.rb,
lib/google/apis/monitoring_v3/representations.rb,
lib/google/apis/monitoring_v3/representations.rb
Overview
Used to schedule the query to run every so many days.
Instance Attribute Summary collapse
-
#execution_time ⇒ Google::Apis::MonitoringV3::TimeOfDay
Represents a time of day.
-
#periodicity ⇒ Fixnum
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Daily
constructor
A new instance of Daily.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Daily
Returns a new instance of Daily.
1253 1254 1255 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1253 def initialize(**args) update!(**args) end |
Instance Attribute Details
#execution_time ⇒ Google::Apis::MonitoringV3::TimeOfDay
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Corresponds to the JSON property executionTime
1245 1246 1247 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1245 def execution_time @execution_time end |
#periodicity ⇒ Fixnum
Required. The number of days between runs. Must be greater than or equal to 1
day and less than or equal to 31 days.
Corresponds to the JSON property periodicity
1251 1252 1253 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1251 def periodicity @periodicity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1258 1259 1260 1261 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1258 def update!(**args) @execution_time = args[:execution_time] if args.key?(:execution_time) @periodicity = args[:periodicity] if args.key?(:periodicity) end |