Class: Google::Apis::MonitoringV3::Field
- Inherits:
-
Object
- Object
- Google::Apis::MonitoringV3::Field
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/monitoring_v3/classes.rb,
lib/google/apis/monitoring_v3/representations.rb,
lib/google/apis/monitoring_v3/representations.rb
Overview
A single field of a message type.New usages of this message as an alternative to FieldDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.
Instance Attribute Summary collapse
-
#cardinality ⇒ String
The field cardinality.
-
#default_value ⇒ String
The string value of the default value of this field.
-
#json_name ⇒ String
The field JSON name.
-
#kind ⇒ String
The field type.
-
#name ⇒ String
The field name.
-
#number ⇒ Fixnum
The field number.
-
#oneof_index ⇒ Fixnum
The index of the field type in Type.oneofs, for message or enumeration types.
-
#options ⇒ Array<Google::Apis::MonitoringV3::Option>
The protocol buffer options.
-
#packed ⇒ Boolean
(also: #packed?)
Whether to use alternative packed wire representation.
-
#type_url ⇒ String
The field type URL, without the scheme, for message or enumeration types.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Field
constructor
A new instance of Field.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Field
Returns a new instance of Field.
1678 1679 1680 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1678 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cardinality ⇒ String
The field cardinality.
Corresponds to the JSON property cardinality
1628 1629 1630 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1628 def cardinality @cardinality end |
#default_value ⇒ String
The string value of the default value of this field. Proto2 syntax only.
Corresponds to the JSON property defaultValue
1633 1634 1635 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1633 def default_value @default_value end |
#json_name ⇒ String
The field JSON name.
Corresponds to the JSON property jsonName
1638 1639 1640 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1638 def json_name @json_name end |
#kind ⇒ String
The field type.
Corresponds to the JSON property kind
1643 1644 1645 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1643 def kind @kind end |
#name ⇒ String
The field name.
Corresponds to the JSON property name
1648 1649 1650 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1648 def name @name end |
#number ⇒ Fixnum
The field number.
Corresponds to the JSON property number
1653 1654 1655 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1653 def number @number end |
#oneof_index ⇒ Fixnum
The index of the field type in Type.oneofs, for message or enumeration types.
The first type has index 1; zero means the type is not in the list.
Corresponds to the JSON property oneofIndex
1659 1660 1661 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1659 def oneof_index @oneof_index end |
#options ⇒ Array<Google::Apis::MonitoringV3::Option>
The protocol buffer options.
Corresponds to the JSON property options
1664 1665 1666 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1664 def @options end |
#packed ⇒ Boolean Also known as: packed?
Whether to use alternative packed wire representation.
Corresponds to the JSON property packed
1669 1670 1671 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1669 def packed @packed end |
#type_url ⇒ String
The field type URL, without the scheme, for message or enumeration types.
Example: "type.googleapis.com/google.protobuf.Timestamp".
Corresponds to the JSON property typeUrl
1676 1677 1678 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1676 def type_url @type_url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1683 1684 1685 1686 1687 1688 1689 1690 1691 1692 1693 1694 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1683 def update!(**args) @cardinality = args[:cardinality] if args.key?(:cardinality) @default_value = args[:default_value] if args.key?(:default_value) @json_name = args[:json_name] if args.key?(:json_name) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @number = args[:number] if args.key?(:number) @oneof_index = args[:oneof_index] if args.key?(:oneof_index) @options = args[:options] if args.key?(:options) @packed = args[:packed] if args.key?(:packed) @type_url = args[:type_url] if args.key?(:type_url) end |