Class: Google::Apis::MonitoringV3::GetNotificationChannelVerificationCodeRequest
- Inherits:
-
Object
- Object
- Google::Apis::MonitoringV3::GetNotificationChannelVerificationCodeRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/monitoring_v3/classes.rb,
lib/google/apis/monitoring_v3/representations.rb,
lib/google/apis/monitoring_v3/representations.rb
Overview
The GetNotificationChannelVerificationCode request.
Instance Attribute Summary collapse
-
#expire_time ⇒ String
The desired expiration time.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GetNotificationChannelVerificationCodeRequest
constructor
A new instance of GetNotificationChannelVerificationCodeRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GetNotificationChannelVerificationCodeRequest
Returns a new instance of GetNotificationChannelVerificationCodeRequest.
1466 1467 1468 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1466 def initialize(**args) update!(**args) end |
Instance Attribute Details
#expire_time ⇒ String
The desired expiration time. If specified, the API will guarantee that the
returned code will not be valid after the specified timestamp; however, the
API cannot guarantee that the returned code will be valid for at least as long
as the requested time (the API puts an upper bound on the amount of time for
which a code may be valid). If omitted, a default expiration will be used,
which may be less than the max permissible expiration (so specifying an
expiration may extend the code's lifetime over omitting an expiration, even
though the API does impose an upper limit on the maximum expiration that is
permitted).
Corresponds to the JSON property expireTime
1464 1465 1466 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1464 def expire_time @expire_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1471 1472 1473 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1471 def update!(**args) @expire_time = args[:expire_time] if args.key?(:expire_time) end |