Class: Google::Apis::MonitoringV3::GetNotificationChannelVerificationCodeResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/monitoring_v3/classes.rb,
lib/google/apis/monitoring_v3/representations.rb,
lib/google/apis/monitoring_v3/representations.rb

Overview

The GetNotificationChannelVerificationCode request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GetNotificationChannelVerificationCodeResponse

Returns a new instance of GetNotificationChannelVerificationCodeResponse.



1495
1496
1497
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1495

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeString

The verification code, which may be used to verify other channels that have an equivalent identity (i.e. other channels of the same type with the same fingerprint such as other email channels with the same email address or other sms channels with the same number). Corresponds to the JSON property code

Returns:

  • (String)


1486
1487
1488
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1486

def code
  @code
end

#expire_timeString

The expiration time associated with the code that was returned. If an expiration was provided in the request, this is the minimum of the requested expiration in the request and the max permitted expiration. Corresponds to the JSON property expireTime

Returns:

  • (String)


1493
1494
1495
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1493

def expire_time
  @expire_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1500
1501
1502
1503
# File 'lib/google/apis/monitoring_v3/classes.rb', line 1500

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
end