Class: Google::Apis::MonitoringV3::ListUptimeCheckIpsResponse
- Inherits:
-
Object
- Object
- Google::Apis::MonitoringV3::ListUptimeCheckIpsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/monitoring_v3/classes.rb,
lib/google/apis/monitoring_v3/representations.rb,
lib/google/apis/monitoring_v3/representations.rb
Overview
The protocol for the ListUptimeCheckIps response.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
This field represents the pagination token to retrieve the next page of results.
-
#uptime_check_ips ⇒ Array<Google::Apis::MonitoringV3::UptimeCheckIp>
The returned list of IP addresses (including region and location) that the checkers run from.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListUptimeCheckIpsResponse
constructor
A new instance of ListUptimeCheckIpsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListUptimeCheckIpsResponse
Returns a new instance of ListUptimeCheckIpsResponse.
2513 2514 2515 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 2513 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
This field represents the pagination token to retrieve the next page of
results. If the value is empty, it means no further results for the request.
To retrieve the next page of results, the value of the next_page_token is
passed to the subsequent List method call (in the request message's page_token
field). NOTE: this field is not yet implemented
Corresponds to the JSON property nextPageToken
2505 2506 2507 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 2505 def next_page_token @next_page_token end |
#uptime_check_ips ⇒ Array<Google::Apis::MonitoringV3::UptimeCheckIp>
The returned list of IP addresses (including region and location) that the
checkers run from.
Corresponds to the JSON property uptimeCheckIps
2511 2512 2513 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 2511 def uptime_check_ips @uptime_check_ips end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2518 2519 2520 2521 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 2518 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @uptime_check_ips = args[:uptime_check_ips] if args.key?(:uptime_check_ips) end |