Class: Google::Apis::MonitoringV3::NotificationChannelStrategy
- Inherits:
-
Object
- Object
- Google::Apis::MonitoringV3::NotificationChannelStrategy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/monitoring_v3/classes.rb,
lib/google/apis/monitoring_v3/representations.rb,
lib/google/apis/monitoring_v3/representations.rb
Overview
Control over how the notification channels in notification_channels are notified when this alert fires, on a per-channel basis.
Instance Attribute Summary collapse
-
#notification_channel_names ⇒ Array<String>
The full REST resource name for the notification channels that these settings apply to.
-
#renotify_interval ⇒ String
The frequency at which to send reminder notifications for open incidents.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NotificationChannelStrategy
constructor
A new instance of NotificationChannelStrategy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NotificationChannelStrategy
Returns a new instance of NotificationChannelStrategy.
3412 3413 3414 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 3412 def initialize(**args) update!(**args) end |
Instance Attribute Details
#notification_channel_names ⇒ Array<String>
The full REST resource name for the notification channels that these settings
apply to. Each of these correspond to the name field in one of the
NotificationChannel objects referenced in the notification_channels field of
this AlertPolicy. The format is: projects/[PROJECT_ID_OR_NUMBER]/
notificationChannels/[CHANNEL_ID]
Corresponds to the JSON property notificationChannelNames
3405 3406 3407 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 3405 def notification_channel_names @notification_channel_names end |
#renotify_interval ⇒ String
The frequency at which to send reminder notifications for open incidents.
Corresponds to the JSON property renotifyInterval
3410 3411 3412 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 3410 def renotify_interval @renotify_interval end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3417 3418 3419 3420 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 3417 def update!(**args) @notification_channel_names = args[:notification_channel_names] if args.key?(:notification_channel_names) @renotify_interval = args[:renotify_interval] if args.key?(:renotify_interval) end |