Class: Google::Apis::MonitoringV3::QueryTimeSeriesResponse
- Inherits:
-
Object
- Object
- Google::Apis::MonitoringV3::QueryTimeSeriesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/monitoring_v3/classes.rb,
lib/google/apis/monitoring_v3/representations.rb,
lib/google/apis/monitoring_v3/representations.rb
Overview
The QueryTimeSeries response. For information about the status of Monitoring Query Language (MQL), see the MQL deprecation notice (https://cloud.google.com/ stackdriver/docs/deprecations/mql).
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
If there are more results than have been returned, then this field is set to a non-empty value.
-
#partial_errors ⇒ Array<Google::Apis::MonitoringV3::Status>
Query execution errors that may have caused the time series data returned to be incomplete.
-
#time_series_data ⇒ Array<Google::Apis::MonitoringV3::TimeSeriesData>
The time series data.
-
#time_series_descriptor ⇒ Google::Apis::MonitoringV3::TimeSeriesDescriptor
A descriptor for the labels and points in a time series.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QueryTimeSeriesResponse
constructor
A new instance of QueryTimeSeriesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QueryTimeSeriesResponse
Returns a new instance of QueryTimeSeriesResponse.
4313 4314 4315 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 4313 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
If there are more results than have been returned, then this field is set to a
non-empty value. To see the additional results, use that value as page_token
in the next call to this method.
Corresponds to the JSON property nextPageToken
4295 4296 4297 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 4295 def next_page_token @next_page_token end |
#partial_errors ⇒ Array<Google::Apis::MonitoringV3::Status>
Query execution errors that may have caused the time series data returned to
be incomplete. The available data will be available in the response.
Corresponds to the JSON property partialErrors
4301 4302 4303 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 4301 def partial_errors @partial_errors end |
#time_series_data ⇒ Array<Google::Apis::MonitoringV3::TimeSeriesData>
The time series data.
Corresponds to the JSON property timeSeriesData
4306 4307 4308 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 4306 def time_series_data @time_series_data end |
#time_series_descriptor ⇒ Google::Apis::MonitoringV3::TimeSeriesDescriptor
A descriptor for the labels and points in a time series.
Corresponds to the JSON property timeSeriesDescriptor
4311 4312 4313 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 4311 def time_series_descriptor @time_series_descriptor end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4318 4319 4320 4321 4322 4323 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 4318 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @partial_errors = args[:partial_errors] if args.key?(:partial_errors) @time_series_data = args[:time_series_data] if args.key?(:time_series_data) @time_series_descriptor = args[:time_series_descriptor] if args.key?(:time_series_descriptor) end |