Class: Google::Apis::MonitoringV3::RowCountTest
- Inherits:
-
Object
- Object
- Google::Apis::MonitoringV3::RowCountTest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/monitoring_v3/classes.rb,
lib/google/apis/monitoring_v3/representations.rb,
lib/google/apis/monitoring_v3/representations.rb
Overview
A test that checks if the number of rows in the result set violates some threshold.
Instance Attribute Summary collapse
-
#comparison ⇒ String
Required.
-
#threshold ⇒ Fixnum
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RowCountTest
constructor
A new instance of RowCountTest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RowCountTest
Returns a new instance of RowCountTest.
4455 4456 4457 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 4455 def initialize(**args) update!(**args) end |
Instance Attribute Details
#comparison ⇒ String
Required. The comparison to apply between the number of rows returned by the
query and the threshold.
Corresponds to the JSON property comparison
4448 4449 4450 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 4448 def comparison @comparison end |
#threshold ⇒ Fixnum
Required. The value against which to compare the row count.
Corresponds to the JSON property threshold
4453 4454 4455 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 4453 def threshold @threshold end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4460 4461 4462 4463 |
# File 'lib/google/apis/monitoring_v3/classes.rb', line 4460 def update!(**args) @comparison = args[:comparison] if args.key?(:comparison) @threshold = args[:threshold] if args.key?(:threshold) end |